@@ -1,6 +1,7 @@
 import abc
 import dataclasses
 import itertools
+import json
 import logging
 import traceback
 from abc import ABC
@@ -84,13 +85,20 @@ class OpenApiServer:
 
     @dataclass
     class Config(OpenApiWrapper.Config):
-        pass
+        write_spec_to_file: str = ""  # empty means skip
 
     def __init__(self, config: Config, context: Context):
         self.context = context
         self.config = config
         self.wrapper = OpenApiWrapper(config, context)
 
+    def _write_spec_to_file(self):
+        if self.config.write_spec_to_file:
+            spec = self.wrapper.get_spec_dict()
+            json_res = json.dumps(spec, indent=2)
+            with open(self.config.write_spec_to_file, "w") as f:
+                f.write(json_res)
+
     def register_handler(self, method: str, path: str, rpc_endpoint: RpcEndpoint) -> None:
         operation_id = rpc_endpoint.operation_id or rpc_endpoint.callable.__name__
         request_body = None
@@ -204,6 +212,7 @@ class OpenApiServer:
             return result
 
         self.context.http_server.register_handler(path, handler, {method})
+        self._write_spec_to_file()
 
 
 class CallTemplate(ParameterAggregation):
